using System;
using System.Threading.Tasks;
using Microsoft.Extensions.Logging;
using Microsoft.Extensions.Options;
using GameStore.Services.Configuration;
using GameStore.Entities.Models;
using GameStore.Services.RandomId;

namespace GameStore.Services.GameStock
{
    internal class GameStockService : IGameStockService
    {
        private readonly IRandomIdService _randomIdGenerator;
        private readonly IOptions<StoreOptions> _storeOptions;
        private readonly ILogger<IGameStockService> _logger;

        public GameStockService(IRandomIdService randomIdService, IOptions<StoreOptions> storeOptions, ILogger<IGameStockService> logger)
        {
            _randomIdGenerator = randomIdService;
            _storeOptions = storeOptions;
            _logger = logger;
        }

        public async Task<Game[]> GetAllGames()
        {
            _logger.LogInformation("Starting Game service method");

            // TODO: call repository to fetch

            return new[]
            {
                new Game
                {
                    StockItemId = _randomIdGenerator.GenerateRandomString(_storeOptions.Value.IdEntropy),
                    GameCodeName = "callofduty",
                    Price = 99m,
                },
                new Game
                {
                    StockItemId = _randomIdGenerator.GenerateRandomString(_storeOptions.Value.IdEntropy),
                    GameCodeName = "wow",
                    Price = 99m,
                },
            };
        }

        public Game GetGame(string codeName)
        {
            if (codeName.Equals("wow", StringComparison.CurrentCultureIgnoreCase))
            {
                return new Game
                {
                    StockItemId = _randomIdGenerator.GenerateRandomString(_storeOptions.Value.IdEntropy),
                    GameCodeName = "wow",
                    Price = 99m,
                };
            }   

            throw new NotImplementedException();
        }

        public Game AddGame(Game game)
        {
            // TODO: call repository to save
            return game;
        }
    }
}