﻿using System.Reflection;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Http;
using Microsoft.AspNetCore.Mvc;
using Microsoft.AspNetCore.Mvc.Infrastructure;
using Microsoft.AspNetCore.Mvc.Routing;
using Microsoft.Extensions.Logging;
using GameStore.Api.Controllers;
using GameStore.Entities.Models;
using GameStore.Services.GameStock;
using GameStore.Services.RandomId;
using NSubstitute;
using Xunit;

namespace GameStore.Api.UnitTests
{
    public class GamesControllerTests
    {
        [Fact]
        public async Task GetsOnlyIdAndPrice()
        {
            // Arrange
            var serviceMock = Substitute.For<IGameStockService>();
            var randomIdMock = Substitute.For<IRandomIdService>();
            var actionContextAccessorMock = Substitute.For<IActionContextAccessor>();
            var httpContextAccessorMock = Substitute.For<IHttpContextAccessor>();
            var urlHelperFactoryMock = Substitute.For<IUrlHelperFactory>();
            var loggerMock = Substitute.For<ILogger<GamesController>>();

            serviceMock.GetAllGames().ReturnsForAnyArgs(new[]
            {
                new Game
                {
                    StockItemId = "testid1",
                    GameCodeName = "callofduty",
                    Price = 99m,
                },
                new Game
                {
                    StockItemId = "testid1",
                    GameCodeName = "wow",
                    Price = 99m,
                },
            });

            // Act
            var controller = new GamesController(serviceMock, randomIdMock, actionContextAccessorMock, httpContextAccessorMock, urlHelperFactoryMock, loggerMock);
            var result = await controller.GetAllGames(0, "", new[] {"GameCodeName", "Price"});

            // Assert
            Assert.IsType<OkObjectResult>(result);

            var games = (Game[]) ((OkObjectResult) result).Value;

            Assert.NotEmpty(games);
            foreach (var game in games)
            {
                Assert.NotNull(game.GameCodeName);
                Assert.NotNull(game.Price);
                Assert.Null(game.StockItemId);
            }
        }
    }
}
