﻿using System;
using Microsoft.Extensions.Logging;
using Microsoft.Extensions.Options;
using GameStore.Services.Configuration;
using GameStore.Services.GameStock;
using GameStore.Services.RandomId;
using NSubstitute;
using Xunit;

namespace GameStore.UnitTests
{
    public class GameStockServiceTests
    {

        [Theory]
        [InlineData("wow")]
        [InlineData("WoW")]
        [InlineData("wOw")]
        public void GetsGameByCodename(string codename)
        {
            // Arrange
            var randomIdMock = Substitute.For<IRandomIdService>();
            var loggerMock = Substitute.For<ILogger<IGameStockService>>();
            var optionsMock = Substitute.For<IOptions<StoreOptions>>();

            optionsMock.Value.Returns(new StoreOptions
            {
                IdEntropy = 5
            });

            randomIdMock.GenerateRandomString(Arg.Any<int>()).Returns(new string('a', 5));

            // Act
            var service = new GameStockService(randomIdMock, optionsMock, loggerMock);
            var result = service.GetGame(codename);

            // Assert
            Assert.NotNull(result);
            Assert.Equal(result.GameCodeName, codename, StringComparer.CurrentCultureIgnoreCase);
        }
    }
}
